@@ -1347,7 +1347,7 @@ def csr_top(isa_yaml, grp_yaml, attr_yaml, aux_info, rvxlen, pkgname, logging =
         if isa_yaml['minstret']['rv'+str(xlen)]['accessible']:
             mod_attr_str = '(*conflict_free="ma_incr_minstret,sbread.mv_csr_minstret"*)'
     extra_reset = ''
-    bsvstr += module_temp.format(pkgname,mod_attr_str, extra_reset) + '\n'
+    bsvstr += top_module_temp.format(pkgname,mod_attr_str, extra_reset) + '\n'
 
     if logging:
         logger.debug('-- Instatiating groups')
